@@ -391,15 +391,22 @@ class SymmetricMatrix:
     idx_map: Dict[str, int]
 
     def __init__(self, data: pd.DataFrame = None):
-        # TODO: use only an upper triangular matrix (how in python?)
+        # TODO: use only an upper triangular matrix => linearize
         if data is not None:
             self.set_data(data)
 
     def set_data(self, data: pd.DataFrame):
-        if any(data.index != data.columns):
+        if np.any(data.index != data.columns):
             raise ValueError(
                 "Input data must be a symmetric matrix"
             )
+        duplicates = data.index.duplicated()
+        if np.any(duplicates):
+            dups = data.index[duplicates]
+            raise ValueError(
+                f"Duplicated indices found in 'SymmetricMatrix' call: "
+                f"{', '.join(dups)}"
+            )
         self.data = data.values
         self.idx_map = {name: idx for idx, name in enumerate(data.index.values)}
 
@@ -520,7 +527,7 @@ class SymmetricMatrix:
         self.idx_map = idx_map_upd
 
     def to_csv(self, *args, **kwargs):
-        indices = np.empty(len(self.idx_map), dtype='<U1')
+        indices = np.empty(len(self.idx_map), dtype=object)
         for key, idx in self.idx_map.items():
             indices[idx] = key
         pd.DataFrame(
